@@ -479,13 +479,7 @@ handle_import(
 	res = handle_import_fname(from_name, is_autoload, &sid);
 	vim_free(from_name);
     }
-    else if (mch_isFullName(tv.vval.v_string)
-#ifdef BACKSLASH_IN_FILENAME
-	    // On MS-Windows omitting the drive is still handled like an
-	    // absolute path, not using 'runtimepath'.
-	    || *tv.vval.v_string == '/' || *tv.vval.v_string == '\\'
-#endif
-	    )
+    else if (mch_isFullName(tv.vval.v_string))
     {
 	// Absolute path: "/tmp/name.vim"
 	res = handle_import_fname(tv.vval.v_string, is_autoload, &sid);
